=======
History
=======

0.1.0 (2020-06-20)
------------------

* First release on PyPI.

0.1.7 (Sep 2020)
----------------

* Migrate to plotly visualisations
* Add MAP and HDI methods
* Add additional helper functions

0.9.0 (2020-10-10)
------------------

* Almost 'final' version
* Improve readmes